@@ -9,7 +9,7 @@ DBD::XMLSimple - Access XML data via the DBI interface
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -54,7 +54,7 @@ use base qw(DBI::DBD::SqlEngine);
 
 use vars qw($VERSION $drh $methods_already_installed);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $drh = undef;
 
 sub driver
@@ -132,6 +132,7 @@ package DBD::XMLSimple::Statement;
 use strict;
 use warnings;
 use XML::Twig;
+use Carp;
 
 @DBD::XMLSimple::Statement::ISA = qw(DBI::DBD::SqlEngine::Statement);
 
@@ -157,16 +158,20 @@ sub open_table($$$$$)
 		my %row;
 		my $index = 0;
 		foreach my $leaf($record->children) {
-			$row{$leaf->name()} = $leaf->field();
-			$col_nums{$leaf->name()} = $index++;
-			push @col_names, $leaf->name() if($rows eq 0);
+			my $key = $leaf->name();
+			$row{$key} = $leaf->field();
+			if(!exists($col_nums{$key})) {
+				$col_nums{$key} = $index++;
+				push @col_names, $key;
+			}
 		}
 		$table{data}->{$record->att('id')} = \%row;
 		$rows++;
 	}
 
-	# FIXME:  This assumes the each of the records in the XML file is
-	# in the same order
+	carp "No data found to import" if($rows == 0);
+	carp "Can't determine column names" if(scalar(@col_names) == 0);
+
 	$data->{'rows'} = $rows;
 
 	$table{'table_name'} = $tname;
@@ -263,17 +268,6 @@ Nigel Horne, C<< <njh at bandsman.co.uk> >>
 
 =head1 BUGS
 
-Fields must be in the same order so this does not work (yet):
-
-    <row id="1">
-        <col1>a</col1>
-        <col2>b</col2>
-    </row>
-    <row id="2">
-        <col2>c</col2>
-        <col1>d</col1>
-    <row>
-
 Change x_import to xmls_import once it's been registered
 
 =head1 SEE ALSO
